# Versjon: 0.0.73

# Chain mal
from ._ch_1.ch_2.ch_3.ch_4_fil import ch_5_fn

# numpy()
from numpy import(
    polyfit
    )

# sympy()
from sympy import (
    ConditionSet,
    core,
    diff,
    Eq,
    FiniteSet,
    Intersection,
    nsolve,
    Reals,
    solve,
    solveset,
    Symbol
    )

# reggis()
from .reggis_fil import (
    reggis,

    # Alias > Right
    reggis_cas,
    regresjon,
    regresjon_cas,
    regresjon_polynom,
    regresjon_polynom_cas,

    # Alias > Reversed
    cas_regresjon,
    cas_regresjon_polynom,
    regresjon_polynom_cas
    )

# superlos()
from .superløs_fil import (
    superløs,

    # Alias > Right
    los,
    losning,
    løs,
    løsning,
    superlos,
    super_los,
    super_løs,

    # Alias > Reversed
    los_super,
    løs_super
    )

# ekstremalpunkt_max()
from .ekstremalpunkt_max_fil import (
    ekstremalpunkt_max,

    # Alias > Right > ...
    ekstremalpunkt_maks,
    ekstremalpunkt_maksimalt,
    toppunkt

    # Alias > Reversed > ...
    )

# overskudd_max()
from .overskudd_max_fil import (
    overskudd_max,

    # Alias > Right
    overskudd_maks,
    overskudd_maksimalt,
    overskudd_mest,
    overskudd_storst,
    overskudd_størst,

    # Alias > Reversed
    maks_overskudd,
    maksimalt_overskudd,
    mest_overskudd,
    storst_overskudd,
    størst_overskudd
    )



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Udir)
# Oppgave 5 Grensekostnaden K'(x) til bedrift 

def ch_5_fn():
    print("Dette er en vellykket chain 5-test!")

print("Kaller ch_5_fn() ...")
ch_5_fn()
